#!/usr/bin/env python

# $Header: /home/cvspublic/jakarta-gump/python/gump/conf.py,v 1.7 2003/05/10 18:20:36 nicolaken Exp $
# $Revision: 1.7 $
# $Date: 2003/05/10 18:20:36 $
#
# ====================================================================
#
# The Apache Software License, Version 1.1
#
# Copyright (c) 2003 The Apache Software Foundation.  All rights
# reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#
# 3. The end-user documentation included with the redistribution, if
#    any, must include the following acknowlegement:
#       "This product includes software developed by the
#        Apache Software Foundation (http://www.apache.org/)."
#    Alternately, this acknowlegement may appear in the software itself,
#    if and wherever such third-party acknowlegements normally appear.
#
# 4. The names "The Jakarta Project", "Alexandria", and "Apache Software
#    Foundation" must not be used to endorse or promote products derived
#    from this software without prior written permission. For written
#    permission, please contact apache@apache.org.
#
# 5. Products derived from this software may not be called "Apache"
#    nor may "Apache" appear in their names without prior written
#    permission of the Apache Group.
#
# THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
# ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
# ====================================================================
#
# This software consists of voluntary contributions made by many
# individuals on behalf of the Apache Software Foundation.  For more
# information on the Apache Software Foundation, please see
# <http://www.apache.org/>.

"""
    Helper Stuff
"""

import logging
import types, StringIO

from gump import log
from gump.launcher import *
from gump.context import *
    
def listDirectoryAsWork(context,directory,name=None):
    ok=0
    if not name: name='list_'+directory
    cmd=getCmdFromString("ls -l "+directory,name)
    try:
        result=execute(cmd)
        ok=result.status==CMD_STATUS_SUCCESS 
        if not ok:
            log.error('Failed to list [' + directory + ']')     
    except Exception, details:
        ok=0
        log.error('Failed to list [' + directory + '] : ' + str(details))
       
    # Update Context
    context.performedWork(CommandWorkItem(WORK_TYPE_DOCUMENT,cmd,result))
       

   
def syncDirectories(context,workspace,type,cwd,sourcedir,destdir,name=None):                
    # :TODO: Make this configurable (once again)
    #if not workspace.sync:
    #  workspace.sync = default.syncCommand
    
    if context.noRSync:
        cmd=Cmd('cp','sync_'+name,dir.work)
        cmd.addParameter('-Rf')
        cmd.addParameter(sourcedir)
        cmd.addParameter(destdir)
    else:
        cmd=Cmd('rsync','rsync_'+name,dir.work)            
        cmd.addParameter('-r')
        cmd.addParameter('-a')
        # Keep it quiet...
        # cmd.addParameter('-v')
        # cmd.addParameter('-v')
        # cmd.addParameter('--stats')        
        cmd.addParameter('--delete')
        cmd.addParameter(sourcedir)
        cmd.addParameter(destdir)

    log.debug(' ------ Sync\'ing : '+ name)
    
    # Perform the Sync
    cmdResult=execute(cmd,workspace.tmpdir)

    work=CommandWorkItem(type,cmd,cmdResult)
    
    return work        
    
def tailFile(file,lines):
    """ Return the last N lines of a file as a list """
    taillines=[]
    try:
        try:
            # Read lines from the file...
            o=open(file, 'r')
            line=o.readline()
            
            while line:
                # Store the lines
                taillines.append(line)
            
                # But dump any before 'lines'
                size=len(taillines)
                if size > lines:
                    del taillines[0:(size-lines)]
                    
                # Read next...
                line=o.readline()
                
        finally:
            if o: o.close()
    except Exception, details:
        log.error('Failed to tail :' + file + ' : ' + str(details))    
                            
    return taillines

def tailFileToString(file,lines):
    return "".join(tailFile(file,lines))
    
if __name__=='__main__':

  # init logging
  logging.basicConfig()

  #set verbosity to show all messages of severity >= default.logLevel
  log.setLevel(default.logLevel)
  
  # dump(log)
  
  if len(sys.argv) > 0:
    print tailFileToString(sys.argv[1], 5  )
  
